@@ -85,6 +85,7 @@ path. Add it with -I<path> to the command line
 //  V8_OS_DARWIN        - Darwin (macOS, iOS)
 //  V8_OS_MACOS         - macOS
 //  V8_OS_IOS           - iOS
+//  V8_OS_TVOS          - tvOS (also sets V8_OS_IOS)
 //  V8_OS_NETBSD        - NetBSD
 //  V8_OS_OPENBSD       - OpenBSD
 //  V8_OS_POSIX         - POSIX compatible (mostly everything except Windows)
@@ -108,6 +109,9 @@ path. Add it with -I<path> to the command line
 # if defined(TARGET_OS_IPHONE) && TARGET_OS_IPHONE
 #  define V8_OS_IOS 1
 #  define V8_OS_STRING "ios"
+#  if defined(TARGET_OS_TV) && TARGET_OS_TV
+#   define V8_OS_TVOS 1
+#  endif
 # else
 #  define V8_OS_MACOS 1
 #  define V8_OS_STRING "macos"
@@ -187,6 +191,7 @@ path. Add it with -I<path> to the command line
 //  V8_TARGET_OS_ANDROID
 //  V8_TARGET_OS_FUCHSIA
 //  V8_TARGET_OS_IOS
+//  V8_TARGET_OS_TVOS (also sets V8_TARGET_OS_IOS)
 //  V8_TARGET_OS_LINUX
 //  V8_TARGET_OS_MACOS
 //  V8_TARGET_OS_WIN
@@ -200,6 +205,7 @@ path. Add it with -I<path> to the command line
 # if !defined(V8_TARGET_OS_ANDROID) \
   && !defined(V8_TARGET_OS_FUCHSIA) \
   && !defined(V8_TARGET_OS_IOS) \
+  && !defined(V8_TARGET_OS_TVOS) \
   && !defined(V8_TARGET_OS_LINUX) \
   && !defined(V8_TARGET_OS_MACOS) \
   && !defined(V8_TARGET_OS_WIN) \
@@ -212,6 +218,7 @@ path. Add it with -I<path> to the command line
 # if defined(V8_TARGET_OS_ANDROID) \
   || defined(V8_TARGET_OS_FUCHSIA) \
   || defined(V8_TARGET_OS_IOS) \
+  || defined(V8_TARGET_OS_TVOS) \
   || defined(V8_TARGET_OS_LINUX) \
   || defined(V8_TARGET_OS_MACOS) \
   || defined(V8_TARGET_OS_WIN) \
@@ -232,6 +239,10 @@ path. Add it with -I<path> to the command line
 # define V8_TARGET_OS_IOS
 #endif
 
+#ifdef V8_OS_TVOS
+# define V8_TARGET_OS_TVOS
+#endif
+
 #ifdef V8_OS_LINUX
 # define V8_TARGET_OS_LINUX
 #endif
@@ -322,6 +333,7 @@ path. Add it with -I<path> to the command line
 //  V8_HAS_CPP_ATTRIBUTE_NODISCARD      - [[nodiscard]] supported
 //  V8_HAS_CPP_ATTRIBUTE_NO_UNIQUE_ADDRESS
 //                                      - [[no_unique_address]] supported
+//  V8_HAS_CPP_ATTRIBUTE_LIFETIME_BOUND - [[clang::lifetimebound]] supported
 //  V8_HAS_BUILTIN_ADD_OVERFLOW         - __builtin_add_overflow() supported
 //  V8_HAS_BUILTIN_BIT_CAST             - __builtin_bit_cast() supported
 //  V8_HAS_BUILTIN_BSWAP16              - __builtin_bswap16() supported
@@ -401,6 +413,7 @@ path. Add it with -I<path> to the command line
 # define V8_HAS_CPP_ATTRIBUTE_NO_UNIQUE_ADDRESS \
     (V8_HAS_CPP_ATTRIBUTE(no_unique_address))
 #endif
+# define V8_HAS_CPP_ATTRIBUTE_LIFETIME_BOUND (V8_HAS_CPP_ATTRIBUTE(clang::lifetimebound))
 
 # define V8_HAS_BUILTIN_ADD_OVERFLOW (__has_builtin(__builtin_add_overflow))
 # define V8_HAS_BUILTIN_ASSUME (__has_builtin(__builtin_assume))
@@ -697,6 +710,17 @@ path. Add it with -I<path> to the command line
 #define V8_NODISCARD /* NOT SUPPORTED */
 #endif
 
+
+// Annotate a function to ensure the function is retained in the compiled binary
+// even if it appears to be unused to the compiler.
+#if V8_HAS_ATTRIBUTE_USED && V8_HAS_ATTRIBUTE_VISIBILITY
+#define V8_SYMBOL_USED \
+  __attribute__((used, visibility("default")))
+#else
+#define V8_SYMBOL_USED /* NOT SUPPORTED */
+#endif
+
+
 // The no_unique_address attribute allows tail padding in a non-static data
 // member to overlap other members of the enclosing class (and in the special
 // case when the type is empty, permits it to fully overlap other members). The
@@ -726,6 +750,41 @@ path. Add it with -I<path> to the command line
 #define V8_NO_UNIQUE_ADDRESS /* NOT SUPPORTED */
 #endif
 
+// Annotates a pointer or reference parameter or return value for a member
+// function as having lifetime intertwined with the instance on which the
+// function is called. For parameters, the function is assumed to store the
+// value into the called-on object, so if the referred-to object is later
+// destroyed, the called-on object is also considered to be dangling. For return
+// values, the value is assumed to point into the called-on object, so if that
+// object is destroyed, the returned value is also considered to be dangling.
+// Useful to diagnose some cases of lifetime errors.
+//
+// See also:
+//   https://clang.llvm.org/docs/AttributeReference.html#lifetimebound
+//
+// Usage:
+// ```
+//   struct S {
+//      S(int* p V8_LIFETIME_BOUND);
+//      int* Get() V8_LIFETIME_BOUND;
+//   };
+//   S Func1() {
+//     int i = 0;
+//     // The following return will not compile; diagnosed as returning address
+//     // of a stack object.
+//     return S(&i);
+//   }
+//   int* Func2(int* p) {
+//     // The following return will not compile; diagnosed as returning address
+//     // of a local temporary.
+//     return S(p).Get();
+//   }
+#if V8_HAS_CPP_ATTRIBUTE_LIFETIME_BOUND
+#define V8_LIFETIME_BOUND [[clang::lifetimebound]]
+#else
+#define V8_LIFETIME_BOUND /* NOT SUPPORTED */
+#endif
+
 // Marks a type as being eligible for the "trivial" ABI despite having a
 // non-trivial destructor or copy/move constructor. Such types can be relocated
 // after construction by simply copying their memory, which makes them eligible
@@ -798,7 +857,8 @@ V8 shared library set USING_V8_SHARED.
 #else  // V8_OS_WIN
 
 // Setup for Linux shared library export.
-#if V8_HAS_ATTRIBUTE_VISIBILITY && (defined(BUILDING_V8_SHARED) || USING_V8_SHARED)
+#if (V8_HAS_ATTRIBUTE_VISIBILITY && \
+     (defined(BUILDING_V8_SHARED) || USING_V8_SHARED))
 # define V8_EXPORT __attribute__((visibility("default")))
 #else
 # define V8_EXPORT
@@ -909,8 +969,6 @@ V8 shared library set USING_V8_SHARED.
 #define V8_TARGET_ARCH_32_BIT 1
 #elif V8_TARGET_ARCH_ARM64
 #define V8_TARGET_ARCH_64_BIT 1
-#elif V8_TARGET_ARCH_MIPS
-#define V8_TARGET_ARCH_32_BIT 1
 #elif V8_TARGET_ARCH_MIPS64
 #define V8_TARGET_ARCH_64_BIT 1
 #elif V8_TARGET_ARCH_LOONG64
@@ -948,8 +1006,10 @@ V8 shared library set USING_V8_SHARED.
 #if (V8_TARGET_ARCH_MIPS64 && !(V8_HOST_ARCH_X64 || V8_HOST_ARCH_MIPS64))
 #error Target architecture mips64 is only supported on mips64 and x64 host
 #endif
-#if (V8_TARGET_ARCH_RISCV64 && !(V8_HOST_ARCH_X64 || V8_HOST_ARCH_RISCV64))
-#error Target architecture riscv64 is only supported on riscv64 and x64 host
+#if (V8_TARGET_ARCH_RISCV64 && \
+     !(V8_HOST_ARCH_X64 || V8_HOST_ARCH_ARM64 || V8_HOST_ARCH_RISCV64))
+#error Target architecture riscv64 is only supported on riscv64, x64, and \
+arm64 host
 #endif
 #if (V8_TARGET_ARCH_RISCV32 && !(V8_HOST_ARCH_IA32 || V8_HOST_ARCH_RISCV32))
 #error Target architecture riscv32 is only supported on riscv32 and ia32 host
